diff --git a/pgadmin/agent/dlgStep.cpp b/pgadmin/agent/dlgStep.cpp
index 943dd08..019b447 100644
--- a/pgadmin/agent/dlgStep.cpp
+++ b/pgadmin/agent/dlgStep.cpp
@@ -21,28 +21,48 @@
 // pointer to controls
 #define txtID               CTRL_TEXT("txtID")
 #define chkEnabled          CTRL_CHECKBOX("chkEnabled")
+#define chkTriggerEnabled   CTRL_CHECKBOX("chkTriggerEnabled")
 #define rbxKind             CTRL_RADIOBOX("rbxKind")
 #define rbxOnError          CTRL_RADIOBOX("rbxOnError")
+#define rbxTriggerKind      CTRL_RADIOBOX("rbxTriggerKind")
+#define rbxTriggerOnError   CTRL_RADIOBOX("rbxTriggerOnError")
 #define pnlDefinition       CTRL_PANEL("pnlDefinition")
+#define pnlTrigger          CTRL_PANEL("pnlTrigger")
 #define txtSqlBox           CTRL_TEXT("txtSqlBox")
+#define txtTriggerSqlBox    CTRL_TEXT("txtTriggerSqlBox")
 #define cbDatabase          CTRL_COMBOBOX2("cbDatabase")
 #define txtConnStr          CTRL_TEXT("txtConnStr")
 #define btnSelDatabase      CTRL_BUTTON("btnSelDatabase")
 #define rbRemoteConn        CTRL_RADIOBUTTON("rbRemoteConn")
 #define rbLocalConn         CTRL_RADIOBUTTON("rbLocalConn")
+#define cbTriggerDatabase          CTRL_COMBOBOX2("cbTriggerDatabase")
+#define txtTriggerConnStr          CTRL_TEXT("txtTriggerConnStr")
+#define btnTriggerSelDatabase      CTRL_BUTTON("btnTriggerSelDatabase")
+#define rbTriggerRemoteConn        CTRL_RADIOBUTTON("rbTriggerRemoteConn")
+#define rbTriggerLocalConn         CTRL_RADIOBUTTON("rbTriggerLocalConn")
 
 #define CTL_SQLBOX  188
+#define CTL_TRIGGERSQLBOX  188
 
 BEGIN_EVENT_TABLE(dlgStep, dlgAgentProperty)
 	EVT_CHECKBOX(XRCID("chkEnabled"),               dlgProperty::OnChange)
+	EVT_CHECKBOX(XRCID("chkTriggerEnabled"),        dlgStep::OnTriggerEnabledChange)
 	EVT_COMBOBOX(XRCID("cbDatabase"),               dlgProperty::OnChange)
+	EVT_COMBOBOX(XRCID("cbTriggerDatabase"),        dlgProperty::OnChange)
 	EVT_RADIOBOX(XRCID("rbxKind"),                  dlgProperty::OnChange)
+	EVT_RADIOBOX(XRCID("rbxTriggerKind"),           dlgProperty::OnChange)
 	EVT_RADIOBOX(XRCID("rbxOnError"),               dlgProperty::OnChange)
+	EVT_RADIOBOX(XRCID("rbxTriggerOnError"),        dlgProperty::OnChange)
 	EVT_TEXT(XRCID("txtConnStr"),                   dlgProperty::OnChange)
+	EVT_TEXT(XRCID("txtTriggerConnStr"),            dlgProperty::OnChange)
 	EVT_STC_MODIFIED(CTL_SQLBOX,                    dlgProperty::OnChangeStc)
+	EVT_STC_MODIFIED(CTL_TRIGGERSQLBOX,             dlgProperty::OnChangeStc)
 	EVT_BUTTON(XRCID("btnSelDatabase"),             dlgStep::OnSelectDatabase)
 	EVT_RADIOBUTTON(XRCID("rbRemoteConn"),          dlgStep::OnSelRemoteConn)
 	EVT_RADIOBUTTON(XRCID("rbLocalConn"),           dlgStep::OnSelLocalConn)
+	EVT_BUTTON(XRCID("btnTriggerSelDatabase"),      dlgStep::OnTriggerSelectDatabase)
+	EVT_RADIOBUTTON(XRCID("rbTriggerRemoteConn"),   dlgStep::OnTriggerSelRemoteConn)
+	EVT_RADIOBUTTON(XRCID("rbTriggerLocalConn"),    dlgStep::OnTriggerSelLocalConn)
 END_EVENT_TABLE();
 
 
@@ -69,7 +89,20 @@ dlgStep::dlgStep(pgaFactory *f, frmMain *frame, pgaStep *node, pgaJob *j)
 	sizer->Add(sqlBox, 1, wxRIGHT | wxGROW, 5);
 	sizer->Detach(placeholder);
 	delete placeholder;
-	sizer->Layout();
+    sizer->Layout();
+
+    if (hasTriggerSupport) 
+    {
+        triggerSqlBox = new ctlSQLBox(pnlTrigger, CTL_TRIGGERSQLBOX, wxDefaultPosition, wxDefaultSize, wxTE_MULTILINE | wxSUNKEN_BORDER | wxTE_RICH2);
+
+	    wxWindow *placeholdertrigger = CTRL_TEXT("txtTriggerSqlBox");
+	    wxSizer *sizertrigger = placeholdertrigger->GetContainingSizer();
+	    sizertrigger->Add(triggerSqlBox, 1, wxRIGHT | wxGROW, 5);
+	    sizertrigger->Detach(placeholdertrigger);
+	    delete placeholdertrigger;
+        sizertrigger->Layout();
+    }
+	
 
 
 	txtID->Disable();
@@ -90,17 +123,30 @@ int dlgStep::Go(bool modal)
 	cbDatabase->Append(wxT(" "));
 	cbDatabase->SetSelection(0);
 
+
+    hasTriggerSupport = connection->TableHasColumn(wxT("pgagent"), wxT("pga_jobsteptrigger"), wxT("jsrid"));
+    if (hasTriggerSupport)
+    {
+	    cbTriggerDatabase->Append(wxT(" "));
+	    cbTriggerDatabase->SetSelection(0);
+    }
+
 	pgSet *db = connection->ExecuteSet(wxT("SELECT datname FROM pg_database"));
 	if (db)
 	{
 		while (!db->Eof())
 		{
 			cbDatabase->Append(db->GetVal(0));
+            if (hasTriggerSupport)
+            {
+			    cbTriggerDatabase->Append(db->GetVal(0));
+            }
 			db->MoveNext();
 		}
 		delete db;
 	}
 
+
 	if (step)
 	{
 		// edit mode
@@ -129,6 +175,49 @@ int dlgStep::Go(bool modal)
 		sqlBox->SetText(step->GetCode());
 
 		chkEnabled->SetValue(step->GetEnabled());
+
+
+        if (hasTriggerSupport)
+        {
+            if (step->GetTriggerXid())
+            {
+                chkTriggerEnabled->SetValue(step->GetTriggerEnabled());
+                pnlTrigger->Enable(step->GetTriggerEnabled());
+		        if (step->HasTriggerConnectionString())
+		        {
+			        rbTriggerRemoteConn->SetValue(true);
+			        txtTriggerConnStr->Enable(true);
+			        txtTriggerConnStr->ChangeValue(step->GetTriggerConnStr());
+			        btnTriggerSelDatabase->Enable(true);
+			        cbTriggerDatabase->Enable(false);
+		        }
+		        else
+		        {
+			        rbTriggerLocalConn->SetValue(true);
+			        if (step->GetTriggerDbname().IsEmpty())
+				        cbTriggerDatabase->SetSelection(0);
+			        else
+				        cbTriggerDatabase->SetValue(step->GetTriggerDbname());
+		        }
+
+                rbxTriggerKind->SetSelection(wxString(wxT("sb")).Find(step->GetTriggerKindChar()));
+		        rbxTriggerOnError->SetSelection(wxString(wxT("fs")).Find(step->GetTriggerOnErrorChar()));
+                triggerSqlBox->SetText(step->GetTriggerCode());
+
+            }
+            else
+            {
+                chkTriggerEnabled->SetValue(false);
+                pnlTrigger->Enable(false);
+            }
+
+        }
+        else
+        {
+            pnlTrigger->Enable(false);
+            chkTriggerEnabled->Enable(false);
+        }
+
 	}
 	else
 	{
@@ -139,6 +228,21 @@ int dlgStep::Go(bool modal)
 		txtConnStr->Enable(false);
 		if (!hasConnStrSupport)
 			rbLocalConn->Enable(false);
+			
+        if(!hasTriggerSupport) 
+        {
+            pnlTrigger->Enable(false);
+            chkTriggerEnabled->Enable(false);
+        }
+        else
+        {
+            rbTriggerLocalConn->SetValue(true);
+	        cbTriggerDatabase->Enable(true);
+	        btnTriggerSelDatabase->Enable(false);
+	        txtTriggerConnStr->Enable(false);
+            chkTriggerEnabled->SetValue(false);
+            pnlTrigger->Enable(false);
+        }
 	}
 
 	returncode = dlgProperty::Go(modal);
@@ -166,6 +270,7 @@ void dlgStep::CheckChange()
 	{
 		enable  =  name != step->GetName()
 		           || chkEnabled->GetValue() != step->GetEnabled()
+                   || chkTriggerEnabled->GetValue() != step->GetTriggerEnabled()
 		           || rbxKind->GetSelection() != wxString(wxT("sb")).Find(step->GetKindChar())
 		           || rbxOnError->GetSelection() != wxString(wxT("fsi")).Find(step->GetOnErrorChar())
 		           || txtComment->GetValue() != step->GetComment()
@@ -195,6 +300,32 @@ void dlgStep::CheckChange()
 				enable = cbDatabase->GetValue().Trim() != step->GetDbname();
 			}
 		}
+
+        if(!enable && hasTriggerSupport && chkTriggerEnabled->GetValue()) 
+        {   
+            enable  =  rbxTriggerKind->GetSelection() != wxString(wxT("sb")).Find(step->GetTriggerKindChar())
+                       || rbxTriggerOnError->GetSelection() != wxString(wxT("fs")).Find(step->GetTriggerOnErrorChar())
+                       || triggerSqlBox->GetText() != step->GetTriggerCode();
+
+
+            if (!enable && rbxTriggerKind->GetSelection() == 0)
+            {
+                if (step->HasTriggerConnectionString())
+                {
+                    if (rbTriggerRemoteConn->GetValue())
+                        enable = txtTriggerConnStr->GetValue().Trim() != step->GetTriggerConnStr();
+                    else
+                        enable = true;
+                }
+                else
+                {
+                    if (rbTriggerRemoteConn->GetValue())
+                        enable = true;
+                    else
+                        enable = cbTriggerDatabase->GetValue().Trim() != step->GetTriggerDbname();
+                }
+            }
+        }   
 	}
 	else
 	{
@@ -253,6 +384,45 @@ void dlgStep::CheckChange()
 		}
 	}
 
+
+    if(hasTriggerSupport && chkTriggerEnabled->GetValue()) 
+    {
+        
+	    CheckValid(enable, triggerSqlBox->GetLength() > 0, _("Please specify trigger code to execute."));
+	    // Disable/enable the database combo
+	    if (rbxTriggerKind->GetSelection() == 1)
+	    {
+		    rbTriggerRemoteConn->Enable(false);
+		    rbTriggerLocalConn->Enable(false);
+		    txtTriggerConnStr->Enable(false);
+		    btnTriggerSelDatabase->Enable(false);
+		    cbTriggerDatabase->Enable(false);
+	    }
+	    else
+	    {
+	        rbTriggerRemoteConn->Enable(true);
+	        rbTriggerLocalConn->Enable(true);
+	        if (rbTriggerRemoteConn->GetValue())
+	        {
+		        wxString validConnStr;
+
+		        btnTriggerSelDatabase->Enable(true);
+		        txtTriggerConnStr->Enable(true);
+		        cbTriggerDatabase->Enable(false);
+		        CheckValid(enable, !txtTriggerConnStr->GetValue().Trim().IsEmpty(), _("Please select a trigger connection string."));
+		        CheckValid(enable, dlgSelectDatabase::getValidConnectionString(txtTriggerConnStr->GetValue().Trim(), validConnStr), _("Please enter a valid trigger connection string"));
+	        }
+	        else
+	        {
+		        cbTriggerDatabase->Enable(true);
+		        btnTriggerSelDatabase->Enable(false);
+		        txtTriggerConnStr->Enable(false);
+		        CheckValid(enable, !cbTriggerDatabase->GetValue().Trim().IsEmpty(), _("Please select a trigger database."));
+	        }
+            
+	    }
+    }
+    
 	EnableOK(enable);
 }
 
@@ -311,7 +481,47 @@ wxString dlgStep::GetInsertSql()
 		{
 			sql += wxT(", ") + connstr;
 		}
-		sql += wxT(";\n");
+//		sql += wxT(";\n");
+        if(hasTriggerSupport && chkTriggerEnabled->GetValue()) 
+        {
+
+            wxString triggerKind = wxT("sb")[rbxTriggerKind->GetSelection()];
+		    wxString triggerOnerror = wxT("fs")[rbxTriggerOnError->GetSelection()];
+		    wxString triggerDb, triggerConnstr;
+
+            if (rbxTriggerKind->GetSelection() == 0)
+		    {
+			    if (hasTriggerSupport && rbTriggerRemoteConn->GetValue())
+			    {
+				    triggerConnstr = qtDbString(txtTriggerConnStr->GetValue().Trim());
+				    triggerDb = wxT("''");
+			    }
+			    else
+			    {
+				    triggerDb = qtDbString(cbTriggerDatabase->GetValue().Trim());
+				    triggerConnstr = wxT("''");
+			    }
+		    }
+		    else
+		    {
+			    triggerDb = wxT("''");
+			    triggerConnstr = wxT("''");
+		    }
+            sql = wxT("WITH returningjstid AS ( ") + sql + wxT(" RETURNING jstid )");
+
+            sql += wxT("INSERT INTO pgagent.pga_jobsteptrigger( jsrjstid, jsrkind, jsrcode, jsrdbname, jsronerror, jsrenabled, jsrconnstr");
+            sql += wxT(")\n ") \
+		           wxT("SELECT (SELECT jstid FROM returningjstid), ") + qtDbString(triggerKind) + wxT(", ")
+		           + qtDbString(triggerSqlBox->GetText()) + wxT(", ") + triggerDb + wxT(", ") + qtDbString(triggerOnerror) + wxT(", TRUE")
+                   + wxT(", ") + triggerConnstr;
+		    
+		    sql += wxT(";\n");
+        }
+        
+		
+        
+
+
 	}
 	return sql;
 }
@@ -431,11 +641,153 @@ wxString dlgStep::GetUpdateSql()
 			      wxT("   SET ") + vars + wxT("\n")
 			      wxT(" WHERE jstid=") + NumToStr(step->GetRecId()) +
 			      wxT(";\n");
+
+
+        
+        if(hasTriggerSupport) 
+        {
+            // Trigger Update
+            if (step->GetTriggerXid()) 
+            {
+                vars = wxT("");
+                
+		        if (chkTriggerEnabled->GetValue() != step->GetTriggerEnabled())
+		        {
+			        if (!vars.IsEmpty())
+				        vars.Append(wxT(", "));
+			        vars.Append(wxT("jsrenabled=") + BoolToStr(chkTriggerEnabled->GetValue()));
+		        }
+                if(chkTriggerEnabled->GetValue()) 
+                {
+                    wxString triggerKind = wxT("sb")[rbxTriggerKind->GetSelection()];
+		            if (triggerKind == wxT("s"))
+		            {
+			            if (rbTriggerRemoteConn->GetValue())
+			            {
+				            if (step->HasTriggerConnectionString())
+				            {
+					            if (txtTriggerConnStr->GetValue().Trim() != step->GetTriggerConnStr())
+					            {
+						            if (!vars.IsEmpty())
+							            vars.Append(wxT(", "));
+						            vars.Append(wxT("jsrconnstr=") + qtDbString(txtTriggerConnStr->GetValue().Trim()));
+					            }
+				            }
+				            else
+				            {
+					            if (!vars.IsEmpty())
+						            vars.Append(wxT(", "));
+					            vars.Append(wxT("jsrconnstr=") + qtDbString(txtTriggerConnStr->GetValue().Trim()) + wxT(", "));
+					            vars.Append(wxT("jsrdbname=''"));
+				            }
+			            }
+			            else
+			            {
+				            if (step->HasTriggerConnectionString())
+				            {
+					            if (!vars.IsEmpty())
+						            vars.Append(wxT(", "));
+					            vars.Append(wxT("jsrdbname=") + qtDbString(cbTriggerDatabase->GetValue().Trim()) + wxT(", "));
+					            vars.Append(wxT("jsrconnstr=''"));
+				            }
+				            else
+				            {
+					            if (cbTriggerDatabase->GetValue().Trim() != step->GetTriggerDbname())
+					            {
+						            if (!vars.IsEmpty())
+							            vars.Append(wxT(", "));
+						            vars.Append(wxT("jsrdbname=") + qtDbString(cbTriggerDatabase->GetValue().Trim()));
+					            }
+				            }
+			            }
+		            }
+		            else if (triggerKind == wxT("s"))
+		            {
+			            if (cbTriggerDatabase->GetValue().Trim() != step->GetTriggerDbname())
+			            {
+				            if (!vars.IsEmpty())
+					            vars.Append(wxT(", "));
+				            vars.Append(wxT("jsrdbname=") + qtDbString(cbTriggerDatabase->GetValue().Trim()));
+			            }
+		            }
+		            else
+		            {
+			            if (!vars.IsEmpty())
+				            vars.Append(wxT(", "));
+			            vars.Append(wxT("jsrdbname=''"));
+			            vars.Append(wxT(", jsrconnstr=''"));
+		            }
+		            if (rbxTriggerKind->GetSelection() != triggerKind)
+		            {
+			            if (!vars.IsEmpty())
+				            vars.Append(wxT(", "));
+			            vars.Append(wxT("jsrkind=") + qtDbString(triggerKind));
+		            }
+		            if (rbxTriggerOnError->GetSelection() != wxString(wxT("fs")).Find(step->GetTriggerOnErrorChar()))
+		            {
+			            wxString onerror = wxT("fs")[rbxTriggerOnError->GetSelection()];
+			            if (!vars.IsEmpty())
+				            vars.Append(wxT(", "));
+			            vars.Append(wxT("jsronerror='") + onerror + wxT("'"));
+		            }
+
+		            if (triggerSqlBox->GetText() != step->GetTriggerCode())
+		            {
+			            {
+				            if (!vars.IsEmpty())
+					            vars.Append(wxT(", "));
+				            vars.Append(wxT("jsrcode=") + qtDbString(triggerSqlBox->GetText()));
+			            }
+		            }
+                }
+                if (!vars.IsEmpty())
+			        sql += wxT("UPDATE pgagent.pga_jobsteptrigger\n")
+			              wxT("   SET ") + vars + wxT("\n")
+			              wxT(" WHERE jsrjstid=") + NumToStr(step->GetRecId()) +
+			              wxT(";\n");
+            }
+            else 
+            {
+
+                wxString triggerKind = wxT("sb")[rbxTriggerKind->GetSelection()];
+		        wxString triggerOnerror = wxT("fs")[rbxTriggerOnError->GetSelection()];
+		        wxString triggerDb, triggerConnstr;
+
+                if (rbxTriggerKind->GetSelection() == 0)
+		        {
+			        if (hasTriggerSupport && rbTriggerRemoteConn->GetValue())
+			        {
+				        triggerConnstr = qtDbString(txtTriggerConnStr->GetValue().Trim());
+				        triggerDb = wxT("''");
+			        }
+			        else
+			        {
+				        triggerDb = qtDbString(cbTriggerDatabase->GetValue().Trim());
+				        triggerConnstr = wxT("''");
+			        }
+		        }
+		        else
+		        {
+			        triggerDb = wxT("''");
+			        triggerConnstr = wxT("''");
+		        }
+                sql += wxT("INSERT INTO pgagent.pga_jobsteptrigger( jsrjstid, jsrkind, jsrcode, jsrdbname, jsronerror, jsrenabled, jsrconnstr");
+                sql += wxT(")\n ") \
+		               wxT("SELECT ") + NumToStr(step->GetRecId()) + wxT(", ") + qtDbString(triggerKind) + wxT(", ")
+		               + qtDbString(triggerSqlBox->GetText()) + wxT(", ") + triggerDb + wxT(", ") + qtDbString(triggerOnerror) + wxT(", TRUE")
+                       + wxT(", ") + triggerConnstr;
+		        
+		        sql += wxT(";\n");
+
+            }
+        }
+
 	}
 	else
 	{
 		// create mode; handled by GetInsertSql()
 	}
+
 	return sql;
 }
 
@@ -480,4 +832,50 @@ void dlgStep::OnSelLocalConn(wxCommandEvent &ev)
 	dlgProperty::OnChange(ev);
 }
 
+void dlgStep::OnTriggerSelectDatabase(wxCommandEvent &ev)
+{
+	dlgSelectDatabase dlgSD(this, wxID_ANY);
+	if (dlgSD.ShowModal() == wxID_OK)
+	{
+		wxString strConnStr = dlgSD.getConnInfo();
+		if (!strConnStr.IsEmpty())
+			txtTriggerConnStr->SetValue(strConnStr);
+	}
+}
+
+void dlgStep::OnTriggerSelRemoteConn(wxCommandEvent &ev)
+{
+	if (rbTriggerRemoteConn->GetValue())
+	{
+		cbTriggerDatabase->Enable(false);
+		btnTriggerSelDatabase->Enable(true);
+		txtTriggerConnStr->Enable(true);
+	}
+	dlgProperty::OnChange(ev);
+}
+
+void dlgStep::OnTriggerSelLocalConn(wxCommandEvent &ev)
+{
+	if (rbTriggerLocalConn->GetValue())
+	{
+		cbTriggerDatabase->Enable(true);
+		btnTriggerSelDatabase->Enable(false);
+		txtTriggerConnStr->Enable(false);
+	}
+	dlgProperty::OnChange(ev);
+}
+
+void dlgStep::OnTriggerEnabledChange(wxCommandEvent &ev)
+{
+	if (chkTriggerEnabled->GetValue())
+	{
+		pnlTrigger->Enable(true);
+	}
+    else 
+    {
+		pnlTrigger->Enable(false);
+    }
+	dlgProperty::OnChange(ev);
+}
+
 
diff --git a/pgadmin/agent/pgaStep.cpp b/pgadmin/agent/pgaStep.cpp
index 8d62977..705c791 100644
--- a/pgadmin/agent/pgaStep.cpp
+++ b/pgadmin/agent/pgaStep.cpp
@@ -76,11 +76,19 @@ wxString pgaStep::GetTranslatedMessage(int kindOfMessage) const
 
 bool pgaStep::IsUpToDate()
 {
+    bool ret = true;
 	wxString sql = wxT("SELECT xmin FROM pgagent.pga_jobstep WHERE jstid = ") + NumToStr(GetRecId());
 	if (!GetConnection() || GetConnection()->ExecuteScalar(sql) != NumToStr(GetXid()))
-		return false;
-	else
-		return true;
+		ret = false;
+
+    if(HasTriggerSupport() && GetTriggerXid())
+    {
+	    sql = wxT("SELECT xmin FROM pgagent.pga_jobsteptrigger WHERE jsrjstid = ") + NumToStr(GetRecId());
+	    if (!GetConnection() || GetConnection()->ExecuteScalar(sql) != NumToStr(GetTriggerXid()))
+		    ret = false;
+    }
+
+    return ret;
 }
 
 bool pgaStep::DropObject(wxFrame *frame, ctlTree *browser, bool cascaded)
@@ -110,8 +118,20 @@ void pgaStep::ShowTreeDetail(ctlTree *browser, frmMain *form, ctlListView *prope
 			properties->AppendItem(_("Connection String"), GetConnStr());
 		properties->AppendItem(_("Code"), GetCode());
 		properties->AppendItem(_("On error"), GetOnError());
-
-		properties->AppendItem(_("Comment"), firstLineOnly(GetComment()));
+        properties->AppendItem(_("Comment"), firstLineOnly(GetComment()));
+        if(HasTriggerSupport() && GetTriggerXid())
+        {
+            properties->AppendYesNoItem(_("Trigger Enabled"), GetTriggerEnabled());
+		    properties->AppendItem(_("Trigger Kind"), GetTriggerKind());
+		    if (GetTriggerConnStr().IsEmpty())
+			    properties->AppendItem(_("Trigger Database"), GetTriggerDbname());
+		    else
+			    properties->AppendItem(_("Trigger Connection String"), GetTriggerConnStr());
+		    properties->AppendItem(_("Trigger Code"), GetTriggerCode());
+		    properties->AppendItem(_("Trigger Event"), GetTriggerOnError());
+        }
+
+		
 	}
 }
 
@@ -189,7 +209,50 @@ pgObject *pgaStepFactory::CreateObjects(pgCollection *collection, ctlTree *brows
 			step->iSetOnError(onerrs);
 			step->iSetComment(steps->GetVal(wxT("jstdesc")));
 
-
+            step->iSetHasTriggerSupport(collection->GetConnection()->TableHasColumn(wxT("pgagent"), wxT("pga_jobsteptrigger"), wxT("jsrid")));
+            if(step->HasTriggerSupport())
+            {
+                pgSet *triggerstep = collection->GetConnection()->ExecuteSet(
+	                       wxT("SELECT xmin, * FROM pgagent.pga_jobsteptrigger\n")
+	                       wxT(" WHERE jsrjstid=") + NumToStr(step->GetRecId()) + wxT("\n"));
+                
+			    step->iSetTriggerXid(triggerstep->GetOid(wxT("xmin")));
+                step->iSetTriggerDbname(triggerstep->GetVal(wxT("jsrdbname")));
+
+                step->iSetTriggerEnabled(triggerstep->GetBool(wxT("jsrenabled")));
+
+			    if (triggerstep->HasColumn(wxT("jsrconnstr")))
+				    step->iSetTriggerConnStr(triggerstep->GetVal(wxT("jsrconnstr")));
+			    step->iSetTriggerCode(triggerstep->GetVal(wxT("jsrcode")));
+
+			    kindc = *triggerstep->GetVal(wxT("jsrkind")).c_str();
+			    switch (kindc)
+			    {
+				    case 'b':
+					    kinds = _("Batch");
+					    break;
+				    case 's':
+					    kinds = wxT("SQL");
+					    break;
+			    }
+			    step->iSetTriggerKindChar(kindc);
+			    step->iSetTriggerKind(kinds);
+
+			    onerrc = *triggerstep->GetVal(wxT("jsronerror")).c_str();
+			    switch (onerrc)
+			    {
+				    case 's':
+					    onerrs = _("Succeed");
+					    break;
+				    case 'f':
+					    onerrs = _("Fail");
+					    break;
+			    }
+
+			    step->iSetTriggerOnErrorChar(onerrc);
+			    step->iSetTriggerOnError(onerrs);
+
+            }
 			if (browser)
 			{
 				browser->AppendObject(collection, step);
@@ -201,6 +264,11 @@ pgObject *pgaStepFactory::CreateObjects(pgCollection *collection, ctlTree *brows
 
 		delete steps;
 	}
+
+
+
+
+
 	return step;
 }
 
diff --git a/pgadmin/include/agent/dlgStep.h b/pgadmin/include/agent/dlgStep.h
index f697770..af7ae1e 100644
--- a/pgadmin/include/agent/dlgStep.h
+++ b/pgadmin/include/agent/dlgStep.h
@@ -51,14 +51,22 @@ private:
 	void OnSelRemoteConn(wxCommandEvent &ev);
 	void OnSelLocalConn(wxCommandEvent &ev);
 	void OnSelectDatabase(wxCommandEvent &ev);
+	void OnTriggerSelRemoteConn(wxCommandEvent &ev);
+	void OnTriggerSelLocalConn(wxCommandEvent &ev);
+	void OnTriggerSelectDatabase(wxCommandEvent &ev);
+	void OnTriggerEnabledChange(wxCommandEvent &ev);
+
+
 
 	virtual bool IsUpToDate();
 
 	long jobId;
 	ctlSQLBox *sqlBox;
+	ctlSQLBox *triggerSqlBox;
 	pgaStep *step;
 	pgaJob *job;
 	bool hasConnStrSupport;
+	bool hasTriggerSupport;
 
 	DECLARE_EVENT_TABLE()
 };
diff --git a/pgadmin/include/agent/pgaStep.h b/pgadmin/include/agent/pgaStep.h
index 273ddd1..697d074 100644
--- a/pgadmin/include/agent/pgaStep.h
+++ b/pgadmin/include/agent/pgaStep.h
@@ -102,6 +102,96 @@ public:
 	{
 		onErrorChar = c;
 	}
+
+
+    void iSetTriggerXid(const OID x)
+    {
+        xtriggerid = x;
+    }
+    OID GetTriggerXid() const 
+    {
+        return xtriggerid;
+    }
+    bool GetTriggerEnabled() const
+	{
+		return triggerEnabled;
+	}
+	void iSetTriggerEnabled(const bool b)
+	{
+		triggerEnabled = b;
+	}
+	wxChar GetTriggerKindChar() const
+	{
+		return triggerKindChar;
+	}
+	void iSetTriggerKindChar(const wxChar c)
+	{
+		triggerKindChar = c;
+	}
+	wxString GetTriggerKind() const
+	{
+		return triggerKind;
+	}
+	void iSetTriggerKind(const wxString &s)
+	{
+		triggerKind = s;
+	}
+	wxString GetTriggerCode() const
+	{
+		return triggerCode;
+	}
+	void iSetTriggerCode(const wxString &s)
+	{
+		triggerCode = s;
+	}
+	wxString GetTriggerDbname() const
+	{
+		return triggerDbname;
+	}
+	void iSetTriggerDbname(const wxString &s)
+	{
+		triggerDbname = s;
+	}
+	wxString GetTriggerConnStr() const
+	{
+		return triggerConnstr;
+	}
+	void iSetTriggerConnStr(const wxString &s)
+	{
+		triggerConnstr = s;
+	}
+	wxString GetTriggerOnError() const
+	{
+		return triggerOnError;
+	}
+	void iSetTriggerOnError(const wxString &s)
+	{
+		triggerOnError = s;
+	}
+	wxChar GetTriggerOnErrorChar() const
+	{
+		return triggerOnErrorChar;
+	}
+	void iSetTriggerOnErrorChar(const wxChar c)
+	{
+		triggerOnErrorChar = c;
+	}
+
+	bool HasTriggerConnectionString() const
+	{
+		return !triggerConnstr.IsEmpty();
+	}
+    bool HasTriggerSupport() const
+    {
+        return triggerSupport;
+    }
+	void iSetHasTriggerSupport(const bool b)
+	{
+		triggerSupport = b;
+	}
+
+
+
 	long GetRecId() const
 	{
 		return recId;
@@ -124,10 +214,11 @@ public:
 	}
 
 private:
-	bool enabled;
-	wxString kind, code, dbname, connstr, onError;
-	wxChar kindChar, onErrorChar;
+	bool enabled,triggerEnabled,triggerSupport;
+	wxString kind, code, dbname, connstr, onError, triggerKind, triggerCode, triggerDbname, triggerConnstr, triggerOnError;
+	wxChar kindChar, onErrorChar,triggerKindChar, triggerOnErrorChar;
 	long recId;
+    OID xtriggerid;
 };
 
 class pgaStepCollection : public pgaJobObjCollection
diff --git a/pgadmin/ui/dlgStep.xrc b/pgadmin/ui/dlgStep.xrc
index a6802a7..a8b2d01 100644
--- a/pgadmin/ui/dlgStep.xrc
+++ b/pgadmin/ui/dlgStep.xrc
@@ -19,7 +19,7 @@
                 <cols>2</cols>
                 <vgap>5</vgap>
                 <hgap>5</hgap>
-                <growablerows>7</growablerows>
+                <growablerows>8</growablerows>
                 <growablecols>1</growablecols>
                 <object class="sizeritem">
                   <object class="wxStaticText" name="stName">
@@ -61,6 +61,21 @@
                   <border>4</border>
                 </object>
                 <object class="sizeritem">
+                  <object class="wxStaticText" name="stTriggerEnabled">
+                    <label>Trigger Enabled</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxCheckBox" name="chkTriggerEnabled">
+                    <label></label>
+                    <checked>0</checked>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
                   <object class="wxStaticText" name="stConnType">
                     <label>Connection Type</label>
                     <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
@@ -214,6 +229,155 @@
               </object>
             </object>
           </object>
+
+          <object class="notebookpage">
+            <label>Trigger</label>
+            <object class="wxPanel" name="pnlTrigger">
+              <object class="wxFlexGridSizer">
+                <cols>2</cols>
+                <vgap>5</vgap>
+                <hgap>5</hgap>
+                <growablerows>4</growablerows>
+                <growablecols>1</growablecols>
+
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stTriggerConnType">
+                    <label>Connection Type</label>
+                    <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <option>1</option>
+                  <object class="wxGridSizer">
+                    <hgap>0</hgap>
+                    <cols>2</cols>
+                    <vgap>0</vgap>
+                    <object class="sizeritem">
+                      <object class="wxRadioButton" name="rbTriggerLocalConn">
+                        <style>wxRB_GROUP</style>
+                        <label>Local</label>
+                        <enable>0</enable>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxRadioButton" name="rbTriggerRemoteConn">
+                        <label>Remote</label>
+                        <enable>0</enable>
+                      </object>
+                      <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                    </object>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stTriggerDatabase">
+                    <label>Database</label>
+                    <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxComboBox" name="cbTriggerDatabase">
+                    <content/>
+                    <style>wxCB_READONLY|wxCB_DROPDOWN</style>
+                    <enable>0</enable>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxBoxSizer">
+                    <orient>wxVERTICAL</orient>
+                    <object class="sizeritem">
+                      <object class="wxStaticText" name="stTriggerConnStr">
+                        <label>Connection String</label>
+                        <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                      </object>
+                      <flag>wxALIGN_TOP|wxTOP|wxLEFT|wxRIGHT</flag>
+                      <border>4</border>
+                    </object>
+                  </object>
+                  <flag>wxTOP</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxFlexGridSizer">
+                    <hgap>0</hgap>
+                    <vgap>0</vgap>
+                    <cols>2</cols>
+                    <growablerows></growablerows>
+                    <growablecols>0</growablecols>
+                    <object class="sizeritem">
+                      <object class="wxTextCtrl" name="txtTriggerConnStr">
+                        <enable>0</enable>
+                      </object>
+                      <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                    </object>
+                    <object class="sizeritem">
+                      <object class="wxButton" name="btnTriggerSelDatabase">
+                        <label>...</label>
+                        <enable>0</enable>
+                        <size>15,-1d</size>
+                      </object>
+                    </object>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxRadioBox" name="rbxTriggerKind">
+                    <content>
+                      <item>SQL</item>
+                      <item>Batch</item>
+                    </content>
+                    <selection>0</selection>
+                    <label>Kind</label>
+                    <dimension>1</dimension>
+                    <style>wxRA_SPECIFY_COLS</style>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxRadioBox" name="rbxTriggerOnError">
+                    <label>Trigger Event</label>
+                    <selection>0</selection>
+                    <content>
+                      <item>Fail</item>
+                      <item>Succeed</item>
+                    </content>
+                    <dimension>1</dimension>
+                    <style>wxRA_SPECIFY_COLS</style>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxTOP|wxLEFT|wxRIGHT</flag>
+                  <border>4</border>
+                </object>
+                <object class="sizeritem">
+                  <object class="wxStaticText" name="stTriggerSqlBox">
+                    <label>Defination</label>
+                  </object>
+                  <flag>wxALIGN_CENTRE_VERTICAL|wxALL</flag>
+                  <border>4</border>
+                </object>
+
+
+
+                <object class="sizeritem">
+                  <object class="wxTextCtrl" name="txtTriggerSqlBox">
+                    <style>wxTE_MULTILINE</style>
+                  </object>
+                  <flag>wxEXPAND|wxALIGN_CENTRE_VERTICAL|wxALL</flag>
+                  <border>4</border>
+                </object>
+              </object>
+            </object>
+          </object>
+
         </object>
         <flag>wxEXPAND|wxALIGN_CENTRE|wxALL</flag>
         <border>3</border>
diff --git a/pgadmin/ui/xrcDialogs.cpp b/pgadmin/ui/xrcDialogs.cpp
index f6673a9..1805d2a 100644
--- a/pgadmin/ui/xrcDialogs.cpp
+++ b/pgadmin/ui/xrcDialogs.cpp
@@ -22548,7 +22548,7 @@ static unsigned char xml_res_file_56[] = {
 10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,
 101,99,116,62,10,60,47,114,101,115,111,117,114,99,101,62,10};
 
-static size_t xml_res_size_57 = 10963;
+static size_t xml_res_size_57 = 18154;
 static unsigned char xml_res_file_57[] = {
 60,63,120,109,108,32,118,101,114,115,105,111,110,61,34,49,46,48,34,32,101,
 110,99,111,100,105,110,103,61,34,73,83,79,45,56,56,53,57,45,49,34,63,62,
@@ -22587,7 +22587,7 @@ static unsigned char xml_res_file_57[] = {
 32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,
 53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,103,114,111,119,97,98,108,101,114,111,119,115,62,55,60,47,103,
+32,32,60,103,114,111,119,97,98,108,101,114,111,119,115,62,56,60,47,103,
 114,111,119,97,98,108,101,114,111,119,115,62,10,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,
 62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,
@@ -22676,64 +22676,212 @@ static unsigned char xml_res_file_57[] = {
 116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
 101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
-120,116,34,32,110,97,109,101,61,34,115,116,67,111,110,110,84,121,112,101,
-34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-108,97,98,101,108,62,67,111,110,110,101,99,116,105,111,110,32,84,121,112,
-101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,
-69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+120,116,34,32,110,97,109,101,61,34,115,116,84,114,105,103,103,101,114,69,
+110,97,98,108,101,100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,108,97,98,101,108,62,84,114,105,103,103,101,114,32,
+69,110,97,98,108,101,100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,104,101,99,107,
+66,111,120,34,32,110,97,109,101,61,34,99,104,107,84,114,105,103,103,101,
+114,69,110,97,98,108,101,100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,47,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,104,101,99,107,101,100,
+62,48,60,47,99,104,101,99,107,101,100,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
+69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
+120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
+114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
+67,111,110,110,84,121,112,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,67,111,110,110,101,99,
+116,105,111,110,32,84,121,112,101,60,47,108,97,98,101,108,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,
+67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
 120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,112,116,105,111,110,62,49,60,
+47,111,112,116,105,111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,48,60,47,104,103,
+97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,99,111,108,115,62,50,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,48,60,47,118,
+103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,82,97,100,105,111,66,117,116,116,111,110,34,32,110,97,109,101,
+61,34,114,98,76,111,99,97,108,67,111,110,110,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,
+101,62,119,120,82,66,95,71,82,79,85,80,60,47,115,116,121,108,101,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,108,97,98,101,108,62,76,111,99,97,108,60,47,108,97,98,101,108,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,101,110,97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,
+84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
-108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,
-73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,
-73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
-101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
-98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
 105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,112,116,105,111,110,62,49,60,47,111,112,116,105,111,110,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,71,114,105,100,83,105,122,
-101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,104,103,97,112,62,48,60,47,104,103,97,112,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,
-47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,118,103,97,112,62,48,60,47,118,103,97,112,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,100,105,
-111,66,117,116,116,111,110,34,32,110,97,109,101,61,34,114,98,76,111,99,
-97,108,67,111,110,110,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,82,66,95,
-71,82,79,85,80,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,
-76,111,99,97,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,97,98,108,101,
-62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
-97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,
-67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,
-71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,82,97,100,105,111,66,117,116,116,111,110,34,32,110,97,109,101,61,34,
+114,98,82,101,109,111,116,101,67,111,110,110,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,82,101,109,111,116,101,60,47,108,97,98,101,108,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,
+97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,
+78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,
+124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,100,105,111,66,
-117,116,116,111,110,34,32,110,97,109,101,61,34,114,98,82,101,109,111,116,
-101,67,111,110,110,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,82,101,109,111,116,101,
-60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,101,110,97,98,108,101,62,48,60,47,101,
-110,97,98,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,
+32,110,97,109,101,61,34,115,116,68,97,116,97,98,97,115,101,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,68,97,116,97,98,97,115,101,60,47,108,97,98,101,108,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,
+67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
+120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
+115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,119,120,67,111,109,98,111,66,111,120,34,32,110,97,109,
+101,61,34,99,98,68,97,116,97,98,97,115,101,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,110,116,101,110,116,47,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,
+116,121,108,101,62,119,120,67,66,95,82,69,65,68,79,78,76,89,124,119,120,
+67,66,95,68,82,79,80,68,79,87,78,60,47,115,116,121,108,101,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,97,98,
+108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
+69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
+120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
+114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,114,105,101,110,116,62,119,120,86,69,
+82,84,73,67,65,76,60,47,111,114,105,101,110,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
+120,116,34,32,110,97,109,101,61,34,115,116,67,111,110,110,83,116,114,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,108,97,98,101,108,62,67,111,110,110,101,99,116,105,111,110,32,
+83,116,114,105,110,103,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,
+76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,65,76,73,71,78,95,84,79,80,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,102,108,97,103,62,119,120,84,79,80,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
+62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,
+115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+104,103,97,112,62,48,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,48,60,47,118,103,
+97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,99,111,108,115,62,50,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,
+114,111,119,115,47,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,62,48,60,47,
+103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,
+108,34,32,110,97,109,101,61,34,116,120,116,67,111,110,110,83,116,114,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,101,110,97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
+119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,
+124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,
+32,110,97,109,101,61,34,98,116,110,83,101,108,68,97,116,97,98,97,115,101,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,108,97,98,101,108,62,46,46,46,60,47,108,97,98,101,108,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,101,110,97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,
+105,122,101,62,49,53,44,45,49,100,60,47,115,105,122,101,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,
@@ -22746,15 +22894,24 @@ static unsigned char xml_res_file_57[] = {
 32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
 114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,116,
-68,97,116,97,98,97,115,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,68,97,116,97,98,97,115,
-101,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,
-69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,
-120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
-99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+82,97,100,105,111,66,111,120,34,32,110,97,109,101,61,34,114,98,120,75,105,
+110,100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,99,111,110,116,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,83,81,76,60,47,
+105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,105,116,101,109,62,66,97,116,99,104,60,47,105,116,101,
+109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,99,111,110,116,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,115,101,108,101,99,116,105,111,110,62,48,60,
+47,115,101,108,101,99,116,105,111,110,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,75,105,110,100,
+60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,100,105,109,101,110,115,105,111,110,62,49,60,47,100,
+105,109,101,110,115,105,111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,82,65,95,83,
+80,69,67,73,70,89,95,67,79,76,83,60,47,115,116,121,108,101,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
 108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,
 73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,
 73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,
@@ -22763,97 +22920,356 @@ static unsigned char xml_res_file_57[] = {
 98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
 105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,111,
-109,98,111,66,111,120,34,32,110,97,109,101,61,34,99,98,68,97,116,97,98,
-97,115,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,99,111,110,116,101,110,116,47,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,67,
-66,95,82,69,65,68,79,78,76,89,124,119,120,67,66,95,68,82,79,80,68,79,87,
-78,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,101,110,97,98,108,101,62,48,60,47,101,110,97,
-98,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
-120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
-108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,66,111,120,83,105,122,101,
-114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,111,114,105,101,110,116,62,119,120,86,69,82,84,73,67,65,76,60,47,111,
-114,105,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,
-97,109,101,61,34,115,116,67,111,110,110,83,116,114,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,
-101,108,62,67,111,110,110,101,99,116,105,111,110,32,83,116,114,105,110,
-103,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,
-71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,
-80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,
-103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,
+100,105,111,66,111,120,34,32,110,97,109,101,61,34,114,98,120,79,110,69,
+114,114,111,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,79,110,32,101,114,114,111,114,60,47,
+108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,115,101,108,101,99,116,105,111,110,62,48,60,47,115,101,108,
+101,99,116,105,111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,99,111,110,116,101,110,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,70,
+97,105,108,60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,83,117,99,99,101,
+101,100,60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,73,103,110,111,114,
+101,60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,99,111,110,116,101,110,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,100,105,109,101,110,
+115,105,111,110,62,49,60,47,100,105,109,101,110,115,105,111,110,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,
+108,101,62,119,120,82,65,95,83,80,69,67,73,70,89,95,67,79,76,83,60,47,115,
+116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,
-78,95,84,79,80,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,
-82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,
-47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,
+120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,
+119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,
+47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,
+84,101,120,116,34,32,110,97,109,101,61,34,115,116,67,111,109,109,101,110,
+116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,108,97,98,101,108,62,67,111,109,109,101,110,116,60,47,108,97,98,101,
+108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,
+95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
+97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,
+97,109,101,61,34,116,120,116,67,111,109,109,101,110,116,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,
+101,62,119,120,84,69,95,77,85,76,84,73,76,73,78,69,60,47,115,116,121,108,
+101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,
+73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,65,
+76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,
+114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,110,111,116,101,98,111,111,107,112,97,103,101,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,68,101,
+102,105,110,105,116,105,111,110,60,47,108,97,98,101,108,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,119,120,80,97,110,101,108,34,32,110,97,109,101,61,34,112,110,108,
+68,101,102,105,110,105,116,105,111,110,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,49,60,47,99,
+111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,
+103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,
+108,101,114,111,119,115,62,48,60,47,103,114,111,119,97,98,108,101,114,111,
+119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,
+111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,
+108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
+84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,83,
+113,108,66,111,120,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,69,95,77,85,76,84,73,
+76,73,78,69,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
+69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,
+114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
 32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,110,111,116,101,
+98,111,111,107,112,97,103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,60,108,97,98,101,108,62,84,114,105,103,103,101,114,60,47,108,97,98,101,
+108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,119,120,80,97,110,101,108,34,32,110,97,109,101,
+61,34,112,110,108,84,114,105,103,103,101,114,34,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,
+47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,118,103,97,112,62,53,60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,53,60,47,104,103,97,112,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,
+97,98,108,101,114,111,119,115,62,52,60,47,103,114,111,119,97,98,108,101,
+114,111,119,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,111,119,
+97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,
+122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
+120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,101,61,34,115,
+116,84,114,105,103,103,101,114,67,111,110,110,84,121,112,101,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,67,111,110,110,101,99,116,105,111,110,32,84,121,112,101,60,47,108,
+97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,
+69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,
+84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
+62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,
+76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,
+101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,112,116,105,111,110,62,49,60,47,111,112,116,105,111,110,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,71,114,105,100,83,105,122,101,114,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+104,103,97,112,62,48,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,50,60,47,99,111,
+108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,118,103,97,112,62,48,60,47,118,103,97,112,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,100,105,111,66,117,
+116,116,111,110,34,32,110,97,109,101,61,34,114,98,84,114,105,103,103,101,
+114,76,111,99,97,108,67,111,110,110,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,
+119,120,82,66,95,71,82,79,85,80,60,47,115,116,121,108,101,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
+98,101,108,62,76,111,99,97,108,60,47,108,97,98,101,108,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,
+97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
+86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,
+119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,100,
+105,111,66,117,116,116,111,110,34,32,110,97,109,101,61,34,114,98,84,114,
+105,103,103,101,114,82,101,109,111,116,101,67,111,110,110,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,
+97,98,101,108,62,82,101,109,111,116,101,60,47,108,97,98,101,108,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+101,110,97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,
+82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,
+70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,
+73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,
+79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
+111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
-119,120,84,79,80,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
+116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,120,
+116,34,32,110,97,109,101,61,34,115,116,84,114,105,103,103,101,114,68,97,
+116,97,98,97,115,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,108,97,98,101,108,62,68,97,116,97,98,97,115,101,60,
+47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,
+84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,
+69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,
+67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,
+71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,
+101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
+105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,67,111,
+109,98,111,66,111,120,34,32,110,97,109,101,61,34,99,98,84,114,105,103,103,
+101,114,68,97,116,97,98,97,115,101,34,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,99,111,110,116,101,110,116,47,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,
+121,108,101,62,119,120,67,66,95,82,69,65,68,79,78,76,89,124,119,120,67,
+66,95,68,82,79,80,68,79,87,78,60,47,115,116,121,108,101,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,97,98,108,
+101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
+69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,
+69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,
+120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
 114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
 47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
 114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,48,60,
-47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,118,103,97,112,62,48,60,47,118,103,97,112,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,108,115,62,
-50,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,114,111,119,115,47,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,
-111,119,97,98,108,101,99,111,108,115,62,48,60,47,103,114,111,119,97,98,
-108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,97,109,
-101,61,34,116,120,116,67,111,110,110,83,116,114,34,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,97,
-98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+66,111,120,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,111,114,105,101,110,116,62,119,120,86,69,
+82,84,73,67,65,76,60,47,111,114,105,101,110,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
+120,116,34,32,110,97,109,101,61,34,115,116,84,114,105,103,103,101,114,67,
+111,110,110,83,116,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,67,111,110,110,
+101,99,116,105,111,110,32,83,116,114,105,110,103,60,47,108,97,98,101,108,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,
-78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,
-124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
-111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
-34,98,116,110,83,101,108,68,97,116,97,98,97,115,101,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,
-101,108,62,46,46,46,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,97,98,108,
-101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,49,53,
-44,45,49,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
+32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,
+95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,
+124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,84,79,80,124,119,120,
+84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
+97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,102,108,97,103,62,119,120,84,79,80,60,47,102,108,97,
+103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,
+114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,
+108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
+32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,
+122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,104,103,97,112,62,48,60,47,104,103,97,112,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,118,103,97,112,62,48,
+60,47,118,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,99,111,108,115,62,50,60,47,99,111,108,115,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,
+97,98,108,101,114,111,119,115,47,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,
+115,62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,
+99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,
+116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,84,114,105,103,
+103,101,114,67,111,110,110,83,116,114,34,62,10,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,110,97,98,108,101,
+62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,
+97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,
+78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,
+76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
 101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
+32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
+114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,34,98,116,110,
+84,114,105,103,103,101,114,83,101,108,68,97,116,97,98,97,115,101,34,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,108,97,98,101,108,62,46,46,46,60,47,108,97,98,101,108,62,10,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,101,
+110,97,98,108,101,62,48,60,47,101,110,97,98,108,101,62,10,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,
+101,62,49,53,44,45,49,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
+68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,
+65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,
+72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,
+114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
+106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,
+116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,100,
+105,111,66,111,120,34,32,110,97,109,101,61,34,114,98,120,84,114,105,103,
+103,101,114,75,105,110,100,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,99,111,110,116,101,110,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,
+62,83,81,76,60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,66,97,116,99,104,
+60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,99,111,110,116,101,110,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,101,108,101,99,116,105,
+111,110,62,48,60,47,115,101,108,101,99,116,105,111,110,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,
+75,105,110,100,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,100,105,109,101,110,115,105,111,110,
+62,49,60,47,100,105,109,101,110,115,105,111,110,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,
+120,82,65,95,83,80,69,67,73,70,89,95,67,79,76,83,60,47,115,116,121,108,
+101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,
+98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,60,102,108,97,103,62,119,120,65,76,73,71,78,95,67,69,78,84,82,69,
+95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,70,84,
+124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,
+47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
+105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
+34,119,120,82,97,100,105,111,66,111,120,34,32,110,97,109,101,61,34,114,
+98,120,84,114,105,103,103,101,114,79,110,69,114,114,111,114,34,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
+108,62,84,114,105,103,103,101,114,32,69,118,101,110,116,60,47,108,97,98,
+101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,60,115,101,108,101,99,116,105,111,110,62,48,60,47,115,101,108,101,99,
+116,105,111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,99,111,110,116,101,110,116,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,70,97,105,
+108,60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,60,105,116,101,109,62,83,117,99,99,101,101,100,
+60,47,105,116,101,109,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,47,99,111,110,116,101,110,116,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,100,105,109,101,110,115,105,
+111,110,62,49,60,47,100,105,109,101,110,115,105,111,110,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,
+62,119,120,82,65,95,83,80,69,67,73,70,89,95,67,79,76,83,60,47,115,116,121,
+108,101,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
+47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
 65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,
 120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,
 108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
@@ -22862,193 +23278,102 @@ static unsigned char xml_res_file_57[] = {
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
 116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,
 10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,82,97,100,105,111,66,111,
-120,34,32,110,97,109,101,61,34,114,98,120,75,105,110,100,34,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,110,116,
-101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,105,116,101,109,62,83,81,76,60,47,105,116,101,109,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,105,
-116,101,109,62,66,97,116,99,104,60,47,105,116,101,109,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,99,111,110,116,101,
-110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,115,101,108,101,99,116,105,111,110,62,48,60,47,115,101,108,101,99,
-116,105,111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,108,97,98,101,108,62,75,105,110,100,60,47,108,97,98,101,108,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,100,
-105,109,101,110,115,105,111,110,62,49,60,47,100,105,109,101,110,115,105,
-111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,115,116,121,108,101,62,119,120,82,65,95,83,80,69,67,73,70,89,95,67,
-79,76,83,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,
-76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,
-84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,84,60,47,102,108,
-97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,
-111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,
-116,32,99,108,97,115,115,61,34,119,120,82,97,100,105,111,66,111,120,34,
-32,110,97,109,101,61,34,114,98,120,79,110,69,114,114,111,114,34,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
-108,62,79,110,32,101,114,114,111,114,60,47,108,97,98,101,108,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,101,108,101,
-99,116,105,111,110,62,48,60,47,115,101,108,101,99,116,105,111,110,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,99,111,110,
-116,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,60,105,116,101,109,62,70,97,105,108,60,47,105,116,101,109,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-60,105,116,101,109,62,83,117,99,99,101,101,100,60,47,105,116,101,109,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-105,116,101,109,62,73,103,110,111,114,101,60,47,105,116,101,109,62,10,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,99,111,110,
-116,101,110,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,60,100,105,109,101,110,115,105,111,110,62,49,60,47,100,105,109,
-101,110,115,105,111,110,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,82,65,95,83,80,69,67,
-73,70,89,95,67,79,76,83,60,47,115,116,121,108,101,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
-82,69,95,86,69,82,84,73,67,65,76,124,119,120,84,79,80,124,119,120,76,69,
-70,84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,
-52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,
+101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,116,105,99,84,101,
+120,116,34,32,110,97,109,101,61,34,115,116,84,114,105,103,103,101,114,83,
+113,108,66,111,120,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,60,108,97,98,101,108,62,68,101,102,105,110,97,116,105,111,
+110,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
 32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
-34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,83,116,97,116,105,99,84,101,120,116,34,32,110,97,109,
-101,61,34,115,116,67,111,109,109,101,110,116,34,62,10,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,67,111,
-109,109,101,110,116,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
-120,65,76,73,71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,
-119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,
-114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,
-114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-84,101,120,116,67,116,114,108,34,32,110,97,109,101,61,34,116,120,116,67,
-111,109,109,101,110,116,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,69,95,77,85,76,
-84,73,76,73,78,69,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,65,76,73,71,
+78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,
+60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,
+99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
+106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,
+109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,
+98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,84,101,120,116,67,
+116,114,108,34,32,110,97,109,101,61,34,116,120,116,84,114,105,103,103,101,
+114,83,113,108,66,111,120,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,84,69,95,77,85,
+76,84,73,76,73,78,69,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
+32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,
+119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,
+69,95,86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,
+62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
+100,101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
 32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,
-120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,95,
-86,69,82,84,73,67,65,76,124,119,120,65,76,76,60,47,102,108,97,103,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,
-101,114,62,52,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
-32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,
+32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
+32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,
+69,78,84,82,69,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,
+32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,
+114,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,
+32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,
+101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,
+100,83,105,122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,99,111,
+108,115,62,52,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,
+60,103,114,111,119,97,98,108,101,99,111,108,115,62,49,60,47,103,114,111,
+119,97,98,108,101,99,111,108,115,62,10,32,32,32,32,32,32,32,32,32,32,60,
+111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,
+116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,
+32,110,97,109,101,61,34,119,120,73,68,95,72,69,76,80,34,62,10,32,32,32,
+32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,72,101,108,112,
+60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,
+108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,76,60,47,102,
+108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,
+101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,
+32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,
+111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,112,97,99,101,114,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,122,101,62,48,44,
+48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,32,32,32,60,47,
+111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
+101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,
+34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
+99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,
+101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,32,32,32,32,32,32,
+32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,79,75,60,47,108,97,
+98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,100,101,102,
+97,117,108,116,62,49,60,47,100,101,102,97,117,108,116,62,10,32,32,32,32,
 32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,110,111,116,101,
-98,111,111,107,112,97,103,101,34,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,60,108,97,98,101,108,62,68,101,102,105,110,105,116,105,111,110,60,47,
-108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,
-101,99,116,32,99,108,97,115,115,61,34,119,120,80,97,110,101,108,34,32,110,
-97,109,101,61,34,112,110,108,68,101,102,105,110,105,116,105,111,110,34,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,119,120,70,108,101,120,71,114,105,100,83,105,
-122,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,
-99,111,108,115,62,49,60,47,99,111,108,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,118,103,97,112,62,53,60,47,118,103,97,112,62,
-10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,104,103,97,112,62,
-53,60,47,104,103,97,112,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,103,114,111,119,97,98,108,101,114,111,119,115,62,48,60,47,103,
-114,111,119,97,98,108,101,114,111,119,115,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,115,
-62,48,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,
-99,108,97,115,115,61,34,119,120,84,101,120,116,67,116,114,108,34,32,110,
-97,109,101,61,34,116,120,116,83,113,108,66,111,120,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,115,116,121,108,101,
-62,119,120,84,69,95,77,85,76,84,73,76,73,78,69,60,47,115,116,121,108,101,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
-106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,
-71,78,95,67,69,78,84,82,69,95,86,69,82,84,73,67,65,76,124,119,120,65,76,
-76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,32,32,60,98,111,114,100,101,114,62,52,60,47,98,111,114,100,101,114,
-62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,
-106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,
-116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,
 32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,
-119,120,65,76,73,71,78,95,67,69,78,84,82,69,124,119,120,65,76,76,60,47,
-102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,
-62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,60,47,111,98,
-106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,
-120,70,108,101,120,71,114,105,100,83,105,122,101,114,34,62,10,32,32,32,
-32,32,32,32,32,32,32,60,99,111,108,115,62,52,60,47,99,111,108,115,62,10,
-32,32,32,32,32,32,32,32,32,32,60,103,114,111,119,97,98,108,101,99,111,108,
-115,62,49,60,47,103,114,111,119,97,98,108,101,99,111,108,115,62,10,32,32,
+119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,
+32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,
+10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,
 32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,
 34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,
 32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,
-66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,72,69,
-76,80,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,
-108,62,72,101,108,112,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,
-32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,
-65,76,76,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-60,98,111,114,100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,
-32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,
-32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,
-112,97,99,101,114,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,115,105,
-122,101,62,48,44,48,100,60,47,115,105,122,101,62,10,32,32,32,32,32,32,32,
-32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,
-60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,
-105,116,101,109,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,
-106,101,99,116,32,99,108,97,115,115,61,34,119,120,66,117,116,116,111,110,
-34,32,110,97,109,101,61,34,119,120,73,68,95,79,75,34,62,10,32,32,32,32,
-32,32,32,32,32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,
-79,75,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-32,32,60,100,101,102,97,117,108,116,62,49,60,47,100,101,102,97,117,108,
-116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
+66,117,116,116,111,110,34,32,110,97,109,101,61,34,119,120,73,68,95,67,65,
+78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,32,32,32,32,32,32,60,108,97,
+98,101,108,62,38,97,109,112,59,67,97,110,99,101,108,60,47,108,97,98,101,
+108,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,
 62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,
 69,88,80,65,78,68,124,119,120,65,76,76,60,47,102,108,97,103,62,10,32,32,
 32,32,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,
 111,114,100,101,114,62,10,32,32,32,32,32,32,32,32,32,32,60,47,111,98,106,
-101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,
-32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,62,10,
-32,32,32,32,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,
-97,115,115,61,34,119,120,66,117,116,116,111,110,34,32,110,97,109,101,61,
-34,119,120,73,68,95,67,65,78,67,69,76,34,62,10,32,32,32,32,32,32,32,32,
-32,32,32,32,32,32,60,108,97,98,101,108,62,38,97,109,112,59,67,97,110,99,
-101,108,60,47,108,97,98,101,108,62,10,32,32,32,32,32,32,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,32,32,32,32,
-60,102,108,97,103,62,119,120,69,88,80,65,78,68,124,119,120,65,76,76,60,
-47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,32,32,32,32,60,98,111,114,
-100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,69,88,80,65,78,68,124,119,120,84,79,80,124,119,120,76,69,70,
-84,124,119,120,82,73,71,72,84,60,47,102,108,97,103,62,10,32,32,32,32,32,
-32,60,47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,60,111,98,106,101,
-99,116,32,99,108,97,115,115,61,34,115,105,122,101,114,105,116,101,109,34,
-62,10,32,32,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,
-115,61,34,119,120,83,116,97,116,117,115,66,97,114,34,32,110,97,109,101,
-61,34,117,110,107,83,116,97,116,117,115,66,97,114,34,62,10,32,32,32,32,
-32,32,32,32,32,32,60,115,116,121,108,101,62,119,120,83,84,95,83,73,90,69,
-71,82,73,80,60,47,115,116,121,108,101,62,10,32,32,32,32,32,32,32,32,60,
-47,111,98,106,101,99,116,62,10,32,32,32,32,32,32,32,32,60,102,108,97,103,
-62,119,120,69,88,80,65,78,68,124,119,120,65,76,73,71,78,95,67,69,78,84,
-82,69,60,47,102,108,97,103,62,10,32,32,32,32,32,32,32,32,60,98,111,114,
-100,101,114,62,51,60,47,98,111,114,100,101,114,62,10,32,32,32,32,32,32,
-60,47,111,98,106,101,99,116,62,10,32,32,32,32,60,47,111,98,106,101,99,116,
-62,10,32,32,60,47,111,98,106,101,99,116,62,10,60,47,114,101,115,111,117,
-114,99,101,62,10};
+101,99,116,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,
+68,124,119,120,84,79,80,124,119,120,76,69,70,84,124,119,120,82,73,71,72,
+84,60,47,102,108,97,103,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,
+116,62,10,32,32,32,32,32,32,60,111,98,106,101,99,116,32,99,108,97,115,115,
+61,34,115,105,122,101,114,105,116,101,109,34,62,10,32,32,32,32,32,32,32,
+32,60,111,98,106,101,99,116,32,99,108,97,115,115,61,34,119,120,83,116,97,
+116,117,115,66,97,114,34,32,110,97,109,101,61,34,117,110,107,83,116,97,
+116,117,115,66,97,114,34,62,10,32,32,32,32,32,32,32,32,32,32,60,115,116,
+121,108,101,62,119,120,83,84,95,83,73,90,69,71,82,73,80,60,47,115,116,121,
+108,101,62,10,32,32,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,10,
+32,32,32,32,32,32,32,32,60,102,108,97,103,62,119,120,69,88,80,65,78,68,
+124,119,120,65,76,73,71,78,95,67,69,78,84,82,69,60,47,102,108,97,103,62,
+10,32,32,32,32,32,32,32,32,60,98,111,114,100,101,114,62,51,60,47,98,111,
+114,100,101,114,62,10,32,32,32,32,32,32,60,47,111,98,106,101,99,116,62,
+10,32,32,32,32,60,47,111,98,106,101,99,116,62,10,32,32,60,47,111,98,106,
+101,99,116,62,10,60,47,114,101,115,111,117,114,99,101,62,10};
 
 static size_t xml_res_size_58 = 7474;
 static unsigned char xml_res_file_58[] = {
@@ -39670,168 +39995,168 @@ void InitXmlResource()
         else wxFileSystem::AddHandler(new wxMemoryFSHandler);
     }
 
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._ddPrecisionScaleDialog.xrc"), xml_res_file_0, xml_res_size_0, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._ddTableNameDialog.xrc"), xml_res_file_1, xml_res_size_1, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgAddFavourite.xrc"), xml_res_file_2, xml_res_size_2, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgAggregate.xrc"), xml_res_file_3, xml_res_size_3, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgCast.xrc"), xml_res_file_4, xml_res_size_4, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgCheck.xrc"), xml_res_file_5, xml_res_size_5, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgCollation.xrc"), xml_res_file_6, xml_res_size_6, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgColumn.xrc"), xml_res_file_7, xml_res_size_7, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgConnect.xrc"), xml_res_file_8, xml_res_size_8, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgConversion.xrc"), xml_res_file_9, xml_res_size_9, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgDatabase.xrc"), xml_res_file_10, xml_res_size_10, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgDirectDbg.xrc"), xml_res_file_11, xml_res_size_11, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgDomain.xrc"), xml_res_file_12, xml_res_size_12, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgEditGridOptions.xrc"), xml_res_file_13, xml_res_size_13, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgEventTrigger.xrc"), xml_res_file_14, xml_res_size_14, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgExtTable.xrc"), xml_res_file_15, xml_res_size_15, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgExtension.xrc"), xml_res_file_16, xml_res_size_16, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgFindReplace.xrc"), xml_res_file_17, xml_res_size_17, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignDataWrapper.xrc"), xml_res_file_18, xml_res_size_18, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignKey.xrc"), xml_res_file_19, xml_res_size_19, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignServer.xrc"), xml_res_file_20, xml_res_size_20, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgForeignTable.xrc"), xml_res_file_21, xml_res_size_21, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgFunction.xrc"), xml_res_file_22, xml_res_size_22, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgGroup.xrc"), xml_res_file_23, xml_res_size_23, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgHbaConfig.xrc"), xml_res_file_24, xml_res_size_24, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgIndex.xrc"), xml_res_file_25, xml_res_size_25, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgIndexConstraint.xrc"), xml_res_file_26, xml_res_size_26, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgJob.xrc"), xml_res_file_27, xml_res_size_27, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgLanguage.xrc"), xml_res_file_28, xml_res_size_28, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgMainConfig.xrc"), xml_res_file_29, xml_res_size_29, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgManageFavourites.xrc"), xml_res_file_30, xml_res_size_30, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgManageMacros.xrc"), xml_res_file_31, xml_res_size_31, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgMoveTablespace.xrc"), xml_res_file_32, xml_res_size_32, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgOperator.xrc"), xml_res_file_33, xml_res_size_33, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgPackage.xrc"), xml_res_file_34, xml_res_size_34, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgPgpassConfig.xrc"), xml_res_file_35, xml_res_size_35, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgReassignDropOwned.xrc"), xml_res_file_36, xml_res_size_36, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepCluster.xrc"), xml_res_file_37, xml_res_size_37, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepClusterUpgrade.xrc"), xml_res_file_38, xml_res_size_38, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepListen.xrc"), xml_res_file_39, xml_res_size_39, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepNode.xrc"), xml_res_file_40, xml_res_size_40, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepPath.xrc"), xml_res_file_41, xml_res_size_41, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSequence.xrc"), xml_res_file_42, xml_res_size_42, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSet.xrc"), xml_res_file_43, xml_res_size_43, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMerge.xrc"), xml_res_file_44, xml_res_size_44, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMove.xrc"), xml_res_file_45, xml_res_size_45, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepSubscription.xrc"), xml_res_file_46, xml_res_size_46, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRepTable.xrc"), xml_res_file_47, xml_res_size_47, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgResourceGroup.xrc"), xml_res_file_48, xml_res_size_48, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRole.xrc"), xml_res_file_49, xml_res_size_49, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgRule.xrc"), xml_res_file_50, xml_res_size_50, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSchedule.xrc"), xml_res_file_51, xml_res_size_51, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSchema.xrc"), xml_res_file_52, xml_res_size_52, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSearchObject.xrc"), xml_res_file_53, xml_res_size_53, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSelectConnection.xrc"), xml_res_file_54, xml_res_size_54, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSequence.xrc"), xml_res_file_55, xml_res_size_55, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgServer.xrc"), xml_res_file_56, xml_res_size_56, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgStep.xrc"), xml_res_file_57, xml_res_size_57, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgSynonym.xrc"), xml_res_file_58, xml_res_size_58, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTable.xrc"), xml_res_file_59, xml_res_size_59, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTablespace.xrc"), xml_res_file_60, xml_res_size_60, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchConfiguration.xrc"), xml_res_file_61, xml_res_size_61, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchDictionary.xrc"), xml_res_file_62, xml_res_size_62, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchParser.xrc"), xml_res_file_63, xml_res_size_63, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchTemplate.xrc"), xml_res_file_64, xml_res_size_64, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgTrigger.xrc"), xml_res_file_65, xml_res_size_65, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgType.xrc"), xml_res_file_66, xml_res_size_66, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgUser.xrc"), xml_res_file_67, xml_res_size_67, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgUserMapping.xrc"), xml_res_file_68, xml_res_size_68, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._dlgView.xrc"), xml_res_file_69, xml_res_size_69, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmBackup.xrc"), xml_res_file_70, xml_res_size_70, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmBackupGlobals.xrc"), xml_res_file_71, xml_res_size_71, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmBackupServer.xrc"), xml_res_file_72, xml_res_size_72, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmExport.xrc"), xml_res_file_73, xml_res_size_73, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmGrantWizard.xrc"), xml_res_file_74, xml_res_size_74, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmHint.xrc"), xml_res_file_75, xml_res_size_75, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmImport.xrc"), xml_res_file_76, xml_res_size_76, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmMaintenance.xrc"), xml_res_file_77, xml_res_size_77, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmOptions.xrc"), xml_res_file_78, xml_res_size_78, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmPassword.xrc"), xml_res_file_79, xml_res_size_79, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmReport.xrc"), xml_res_file_80, xml_res_size_80, wxT("text/xml"));
-    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._frmRestore.xrc"), xml_res_file_81, xml_res_size_81, wxT("text/xml"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._ddPrecisionScaleDialog.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._ddTableNameDialog.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgAddFavourite.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgAggregate.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgCast.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgCheck.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgCollation.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgColumn.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgConnect.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgConversion.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgDatabase.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgDirectDbg.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgDomain.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgEditGridOptions.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgEventTrigger.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgExtTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgExtension.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgFindReplace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignDataWrapper.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignKey.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgForeignTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgFunction.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgGroup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgHbaConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgIndex.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgIndexConstraint.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgJob.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgLanguage.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgMainConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgManageFavourites.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgManageMacros.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgMoveTablespace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgOperator.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgPackage.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgPgpassConfig.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgReassignDropOwned.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepCluster.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepClusterUpgrade.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepListen.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepNode.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepPath.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSequence.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSet.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMerge.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSetMove.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepSubscription.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRepTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgResourceGroup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRole.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgRule.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSchedule.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSchema.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSearchObject.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSelectConnection.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSequence.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgStep.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgSynonym.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTable.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTablespace.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchConfiguration.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchDictionary.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchParser.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTextSearchTemplate.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgTrigger.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgType.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgUser.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgUserMapping.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._dlgView.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmBackup.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmBackupGlobals.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmBackupServer.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmExport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmGrantWizard.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmHint.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmImport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmMaintenance.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmOptions.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmPassword.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmReport.xrc"));
-    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._frmRestore.xrc"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddPrecisionScaleDialog.xrc"), xml_res_file_0, xml_res_size_0, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddTableNameDialog.xrc"), xml_res_file_1, xml_res_size_1, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAddFavourite.xrc"), xml_res_file_2, xml_res_size_2, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAggregate.xrc"), xml_res_file_3, xml_res_size_3, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCast.xrc"), xml_res_file_4, xml_res_size_4, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCheck.xrc"), xml_res_file_5, xml_res_size_5, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCollation.xrc"), xml_res_file_6, xml_res_size_6, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgColumn.xrc"), xml_res_file_7, xml_res_size_7, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConnect.xrc"), xml_res_file_8, xml_res_size_8, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConversion.xrc"), xml_res_file_9, xml_res_size_9, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDatabase.xrc"), xml_res_file_10, xml_res_size_10, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDirectDbg.xrc"), xml_res_file_11, xml_res_size_11, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDomain.xrc"), xml_res_file_12, xml_res_size_12, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEditGridOptions.xrc"), xml_res_file_13, xml_res_size_13, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEventTrigger.xrc"), xml_res_file_14, xml_res_size_14, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtTable.xrc"), xml_res_file_15, xml_res_size_15, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtension.xrc"), xml_res_file_16, xml_res_size_16, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFindReplace.xrc"), xml_res_file_17, xml_res_size_17, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignDataWrapper.xrc"), xml_res_file_18, xml_res_size_18, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignKey.xrc"), xml_res_file_19, xml_res_size_19, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignServer.xrc"), xml_res_file_20, xml_res_size_20, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignTable.xrc"), xml_res_file_21, xml_res_size_21, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFunction.xrc"), xml_res_file_22, xml_res_size_22, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgGroup.xrc"), xml_res_file_23, xml_res_size_23, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgHbaConfig.xrc"), xml_res_file_24, xml_res_size_24, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndex.xrc"), xml_res_file_25, xml_res_size_25, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndexConstraint.xrc"), xml_res_file_26, xml_res_size_26, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgJob.xrc"), xml_res_file_27, xml_res_size_27, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgLanguage.xrc"), xml_res_file_28, xml_res_size_28, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMainConfig.xrc"), xml_res_file_29, xml_res_size_29, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageFavourites.xrc"), xml_res_file_30, xml_res_size_30, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageMacros.xrc"), xml_res_file_31, xml_res_size_31, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMoveTablespace.xrc"), xml_res_file_32, xml_res_size_32, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgOperator.xrc"), xml_res_file_33, xml_res_size_33, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPackage.xrc"), xml_res_file_34, xml_res_size_34, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPgpassConfig.xrc"), xml_res_file_35, xml_res_size_35, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgReassignDropOwned.xrc"), xml_res_file_36, xml_res_size_36, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepCluster.xrc"), xml_res_file_37, xml_res_size_37, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepClusterUpgrade.xrc"), xml_res_file_38, xml_res_size_38, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepListen.xrc"), xml_res_file_39, xml_res_size_39, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepNode.xrc"), xml_res_file_40, xml_res_size_40, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepPath.xrc"), xml_res_file_41, xml_res_size_41, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSequence.xrc"), xml_res_file_42, xml_res_size_42, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSet.xrc"), xml_res_file_43, xml_res_size_43, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMerge.xrc"), xml_res_file_44, xml_res_size_44, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMove.xrc"), xml_res_file_45, xml_res_size_45, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSubscription.xrc"), xml_res_file_46, xml_res_size_46, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepTable.xrc"), xml_res_file_47, xml_res_size_47, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgResourceGroup.xrc"), xml_res_file_48, xml_res_size_48, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRole.xrc"), xml_res_file_49, xml_res_size_49, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRule.xrc"), xml_res_file_50, xml_res_size_50, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchedule.xrc"), xml_res_file_51, xml_res_size_51, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchema.xrc"), xml_res_file_52, xml_res_size_52, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSearchObject.xrc"), xml_res_file_53, xml_res_size_53, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSelectConnection.xrc"), xml_res_file_54, xml_res_size_54, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSequence.xrc"), xml_res_file_55, xml_res_size_55, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgServer.xrc"), xml_res_file_56, xml_res_size_56, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgStep.xrc"), xml_res_file_57, xml_res_size_57, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSynonym.xrc"), xml_res_file_58, xml_res_size_58, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTable.xrc"), xml_res_file_59, xml_res_size_59, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTablespace.xrc"), xml_res_file_60, xml_res_size_60, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchConfiguration.xrc"), xml_res_file_61, xml_res_size_61, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchDictionary.xrc"), xml_res_file_62, xml_res_size_62, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchParser.xrc"), xml_res_file_63, xml_res_size_63, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchTemplate.xrc"), xml_res_file_64, xml_res_size_64, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTrigger.xrc"), xml_res_file_65, xml_res_size_65, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgType.xrc"), xml_res_file_66, xml_res_size_66, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUser.xrc"), xml_res_file_67, xml_res_size_67, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUserMapping.xrc"), xml_res_file_68, xml_res_size_68, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgView.xrc"), xml_res_file_69, xml_res_size_69, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackup.xrc"), xml_res_file_70, xml_res_size_70, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupGlobals.xrc"), xml_res_file_71, xml_res_size_71, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupServer.xrc"), xml_res_file_72, xml_res_size_72, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmExport.xrc"), xml_res_file_73, xml_res_size_73, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmGrantWizard.xrc"), xml_res_file_74, xml_res_size_74, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmHint.xrc"), xml_res_file_75, xml_res_size_75, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmImport.xrc"), xml_res_file_76, xml_res_size_76, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmMaintenance.xrc"), xml_res_file_77, xml_res_size_77, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmOptions.xrc"), xml_res_file_78, xml_res_size_78, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmPassword.xrc"), xml_res_file_79, xml_res_size_79, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmReport.xrc"), xml_res_file_80, xml_res_size_80, wxT("text/xml"));
+    XRC_ADD_FILE(wxT("XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmRestore.xrc"), xml_res_file_81, xml_res_size_81, wxT("text/xml"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddPrecisionScaleDialog.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_ddTableNameDialog.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAddFavourite.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgAggregate.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCast.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCheck.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgCollation.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgColumn.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConnect.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgConversion.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDatabase.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDirectDbg.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgDomain.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEditGridOptions.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgEventTrigger.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgExtension.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFindReplace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignDataWrapper.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignKey.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgForeignTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgFunction.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgGroup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgHbaConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndex.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgIndexConstraint.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgJob.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgLanguage.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMainConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageFavourites.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgManageMacros.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgMoveTablespace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgOperator.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPackage.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgPgpassConfig.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgReassignDropOwned.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepCluster.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepClusterUpgrade.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepListen.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepNode.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepPath.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSequence.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSet.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMerge.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSetMove.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepSubscription.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRepTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgResourceGroup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRole.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgRule.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchedule.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSchema.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSearchObject.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSelectConnection.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSequence.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgStep.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgSynonym.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTable.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTablespace.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchConfiguration.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchDictionary.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchParser.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTextSearchTemplate.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgTrigger.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgType.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUser.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgUserMapping.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_dlgView.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackup.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupGlobals.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmBackupServer.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmExport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmGrantWizard.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmHint.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmImport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmMaintenance.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmOptions.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmPassword.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmReport.xrc"));
+    wxXmlResource::Get()->Load(wxT("memory:XRC_resource/xrcDialogs.cpp.new$._pgadmin_ui_frmRestore.xrc"));
 }
